@@ -81,7 +81,8 @@ camel_gw_listener_class_init (CamelGwListenerClass *class)
 }
 
 static void
-camel_gw_listener_init (CamelGwListener *config_listener,  CamelGwListenerClass *class)
+camel_gw_listener_init (CamelGwListener *config_listener,
+                        CamelGwListenerClass *class)
 {
 	config_listener->priv = g_new0 (CamelGwListenerPrivate, 1);
 }
@@ -140,7 +141,7 @@ is_groupwise_account (EAccount *account)
 
 /* looks up for an existing groupwise account info in the groupwise_accounts list based on uid */
 
-static GwAccountInfo*
+static GwAccountInfo *
 lookup_account_info (const gchar *key)
 {
 	GList *list;
@@ -182,7 +183,7 @@ add_esource (const gchar *conf_key,
 	ESourceList *source_list;
 	ESourceGroup *group;
 	ESource *source;
-	GConfClient* client;
+	GConfClient * client;
 	GSList *ids, *temp;
 	CamelNetworkSecurityMethod security_method;
 	const gchar *source_selection_key;
@@ -297,12 +298,15 @@ add_esource (const gchar *conf_key,
 }
 
 static void
-remove_esource (const gchar *conf_key, const gchar *group_name, gchar * source_name, const gchar * relative_uri)
+remove_esource (const gchar *conf_key,
+                const gchar *group_name,
+                gchar *source_name,
+                const gchar *relative_uri)
 {
 	ESourceList *list;
 	GSList *groups;
 	gboolean found_group;
-	GConfClient* client;
+	GConfClient * client;
 	GSList *ids;
 	GSList *node_tobe_deleted;
 	const gchar *source_selection_key;
@@ -371,14 +375,17 @@ remove_esource (const gchar *conf_key, const gchar *group_name, gchar * source_n
 /* looks up for e-source with having same info as old_account_info and changes its values passed in new values */
 
 static void
-modify_esource (const gchar * conf_key, GwAccountInfo *old_account_info, EAccount *a, CamelURL *new_url)
+modify_esource (const gchar *conf_key,
+                GwAccountInfo *old_account_info,
+                EAccount *a,
+                CamelURL *new_url)
 {
 	ESourceList *list;
 	GSList *groups;
 	gchar *old_relative_uri;
 	CamelURL *url;
 	gboolean found_group;
-	GConfClient* client;
+	GConfClient * client;
 	CamelSettings *settings;
 	CamelNetworkSecurityMethod security_method;
 	const gchar *poa_address;
@@ -484,7 +491,7 @@ modify_esource (const gchar * conf_key, GwAccountInfo *old_account_info, EAccoun
 
 }
 /* add sources for calendar and tasks if the account added is groupwise account
-   adds the new account info to  groupwise_accounts list */
+ * adds the new account info to  groupwise_accounts list */
 
 static void
 add_calendar_tasks_sources (GwAccountInfo *info)
@@ -501,7 +508,7 @@ add_calendar_tasks_sources (GwAccountInfo *info)
 }
 
 /* removes calendar and tasks sources if the account removed is groupwise account
-   removes the the account info from groupwise_account list */
+ * removes the the account info from groupwise_account list */
 
 static void
 remove_calendar_tasks_sources (GwAccountInfo *info)
@@ -526,7 +533,7 @@ remove_calendar_tasks_sources (GwAccountInfo *info)
 
 }
 
-static GList*
+static GList *
 get_addressbook_names_from_server (gchar *source_url)
 {
 	CamelSettings *settings;
@@ -542,7 +549,7 @@ get_addressbook_names_from_server (gchar *source_url)
 	gchar *password_prompt;
 	gchar *uri;
 	const gchar *poa_address;
-	guint32 flags = E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET;
+	guint32 flags = E_PASSWORDS_REMEMBER_FOREVER | E_PASSWORDS_SECRET;
 	CamelNetworkSecurityMethod security_method;
 	const gchar *scheme;
 	guint16 soap_port;
@@ -630,7 +637,8 @@ get_addressbook_names_from_server (gchar *source_url)
 }
 
 static void
-add_proxy_sources (GwAccountInfo *info, const gchar *parent_name)
+add_proxy_sources (GwAccountInfo *info,
+                   const gchar *parent_name)
 {
 	CamelURL *url;
 	gchar *color;
@@ -661,7 +669,7 @@ add_addressbook_sources (EAccount *account)
 	ESource *source;
 	gchar *base_uri;
 	GList *books_list, *temp_list;
-	GConfClient* client;
+	GConfClient * client;
 	const gchar *use_ssl;
 	const gchar *poa_address;
 	gboolean is_frequent_contacts = FALSE, is_writable = FALSE;
@@ -778,7 +786,7 @@ add_addressbook_sources (EAccount *account)
 
 static void
 modify_addressbook_sources (EAccount *account,
-                            GwAccountInfo *existing_account_info )
+                            GwAccountInfo *existing_account_info)
 {
 	CamelSettings *settings;
 	CamelURL *url;
@@ -933,7 +941,8 @@ remove_addressbook_sources (GwAccountInfo *existing_account_info)
 }
 
 static void
-account_added (EAccountList *account_listener, EAccount *account)
+account_added (EAccountList *account_listener,
+               EAccount *account)
 {
 
 	GwAccountInfo *info;
@@ -968,7 +977,8 @@ account_added (EAccountList *account_listener, EAccount *account)
 }
 
 static void
-account_removed (EAccountList *account_listener, EAccount *account)
+account_removed (EAccountList *account_listener,
+                 EAccount *account)
 {
 	GwAccountInfo *info;
 
@@ -989,7 +999,8 @@ account_removed (EAccountList *account_listener, EAccount *account)
 }
 
 static void
-account_changed (EAccountList *account_listener, EAccount *account)
+account_changed (EAccountList *account_listener,
+                 EAccount *account)
 {
 	gboolean is_gw_account;
 	CamelURL *old_url, *new_url;
@@ -1093,8 +1104,8 @@ account_changed (EAccountList *account_listener, EAccount *account)
 }
 
 static void
-prune_proxies (void) {
-
+prune_proxies (void)
+{
 	EAccountList *account_list;
 	ESourceList *sources;
 	ESourceGroup *group;
@@ -1111,7 +1122,7 @@ prune_proxies (void) {
 	account_list = e_get_account_list ();
 	e_account_list_prune_proxies (account_list);
 
-	for (i=0; i<3; i++) {
+	for (i = 0; i < 3; i++) {
 	if (e_cal_client_get_sources (&sources, types[i], &err)) {
 		/* peek groupwise id and prune for proxies. */
 		groups = e_source_list_peek_groups (sources);
@@ -1134,8 +1145,8 @@ prune_proxies (void) {
 		e_source_list_sync (sources, NULL);
 	}
 	}
-
 }
+
 static void
 camel_gw_listener_construct (CamelGwListener *config_listener)
 {
@@ -1190,7 +1201,7 @@ camel_gw_listener_get_type (void)
 	return camel_gw_listener_type;
 }
 
-CamelGwListener*
+CamelGwListener *
 camel_gw_listener_new (void)
 {
 	CamelGwListener *config_listener;
